| Title: | Encoder for Google 'Pluscodes' |
|---|---|
| Description: | Retrieves a 'pluscode' by inputting latitude and longitude. Includes additional functions to retrieve neighbouring 'pluscodes'. |
| Authors: | Michael Doyle |
| Maintainer: | Michael Doyle <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-10 08:36:04 UTC |
| Source: | https://github.com/cran/pluscode |
This package retrieves the easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_eastneighbour(pluscode)pluscode_eastneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_eastneighbour("9C4MGC2M+H4")pluscode_eastneighbour("9C4MGC2M+H4")
This package retrieves a pluscode by inputting latitude and longitude
pluscode_encode(lats, lngs, precision)pluscode_encode(lats, lngs, precision)
lats |
A valid latitude within the range -90 to 90 |
lngs |
A valid latitude within the range -180 to 180 |
precision |
Options are 2, 4, 8, or 10 |
pluscode_encode(52.501450, -6.567180, 8)pluscode_encode(52.501450, -6.567180, 8)
This function retrieves the neighbouring pluscodes of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_neighbours(pluscode)pluscode_neighbours(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_neighbours("9C4MGC2M+H4")pluscode_neighbours("9C4MGC2M+H4")
This package retrieves the north-easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_northeastneighbour(pluscode)pluscode_northeastneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_northeastneighbour("9C4MGC2M+H4")pluscode_northeastneighbour("9C4MGC2M+H4")
This package retrieves the northerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_northneighbour(pluscode)pluscode_northneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_northneighbour("9C4MGC2M+H4")pluscode_northneighbour("9C4MGC2M+H4")
This package retrieves the north-westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_northwestneighbour(pluscode)pluscode_northwestneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_northwestneighbour("9C4MGC2M+H4")pluscode_northwestneighbour("9C4MGC2M+H4")
This package retrieves the south-easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_southeastneighbour(pluscode)pluscode_southeastneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_southeastneighbour("9C4MGC2M+H4")pluscode_southeastneighbour("9C4MGC2M+H4")
This package retrieves the southerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_southneighbour(pluscode)pluscode_southneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_southneighbour("9C4MGC2M+H4")pluscode_southneighbour("9C4MGC2M+H4")
This package retrieves the south-westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_southwestneighbour(pluscode)pluscode_southwestneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_southwestneighbour("9C4MGC2M+H4")pluscode_southwestneighbour("9C4MGC2M+H4")
This package retrieves the westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)
pluscode_westneighbour(pluscode)pluscode_westneighbour(pluscode)
pluscode |
A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included) |
pluscode_westneighbour("9C4MGC2M+H4")pluscode_westneighbour("9C4MGC2M+H4")