Welcome to ClientVPS Mirrors

Help for package pluscode
Type: Package
Title: Encoder for Google 'Pluscodes'
Version: 0.1.0
Author: Michael Doyle
Maintainer: Michael Doyle <michaeledoyle7@gmail.com>
Description: Retrieves a 'pluscode' by inputting latitude and longitude. Includes additional functions to retrieve neighbouring 'pluscodes'.
License: GPL-2
LazyData: FALSE
Imports: httr, jsonlite
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2018-11-05 14:01:37 UTC; michael.doyle@paddypowerbetfair.com
Repository: CRAN
Date/Publication: 2018-11-14 15:00:03 UTC

Pluscode East Neighbour

Description

This package retrieves the easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_eastneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_eastneighbour("9C4MGC2M+H4")


Pluscode Encoder

Description

This package retrieves a pluscode by inputting latitude and longitude

Usage

pluscode_encode(lats, lngs, precision)

Arguments

lats

A valid latitude within the range -90 to 90

lngs

A valid latitude within the range -180 to 180

precision

Options are 2, 4, 8, or 10

Examples

pluscode_encode(52.501450, -6.567180, 8)


Pluscode Neighbours

Description

This function retrieves the neighbouring pluscodes of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_neighbours(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_neighbours("9C4MGC2M+H4")


Pluscode Northeast Neighbour

Description

This package retrieves the north-easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_northeastneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_northeastneighbour("9C4MGC2M+H4")


Pluscode North Neighbour

Description

This package retrieves the northerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_northneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_northneighbour("9C4MGC2M+H4")


Pluscode Northwest Neighbour

Description

This package retrieves the north-westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_northwestneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_northwestneighbour("9C4MGC2M+H4")


Pluscode Southeast Neighbour

Description

This package retrieves the south-easterly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_southeastneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_southeastneighbour("9C4MGC2M+H4")


Pluscode South Neighbour

Description

This package retrieves the southerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_southneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_southneighbour("9C4MGC2M+H4")


Pluscode Southwest Neighbour

Description

This package retrieves the south-westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_southwestneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_southwestneighbour("9C4MGC2M+H4")


Pluscode West Neighbour

Description

This package retrieves the westerly neighbour of a valid pluscode, with a precision of 2, 4, 8, or 10 excluding the plus sign (which can be included)

Usage

pluscode_westneighbour(pluscode)

Arguments

pluscode

A valid pluscod 2, 4, 8, or 10 characters in length excluding the plus sign (which can be included)

Examples

pluscode_westneighbour("9C4MGC2M+H4")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.